@@ -12,17 +12,18 @@ library(logitr)
 # take much longer to build
 mxl_pref <- readRDS(here::here('inst', 'extdata', 'mxl_pref.Rds'))
 mxl_wtp  <- readRDS(here::here('inst', 'extdata', 'mxl_wtp.Rds'))
+mxl_pref_cor <- readRDS(here::here('inst', 'extdata', 'mxl_pref_cor.Rds'))
 
 ## ----eval=FALSE---------------------------------------------------------------
 #  library("logitr")
 #  
 #  mxl_pref <- logitr(
 #    data     = yogurt,
-#    choice   = 'choice',
+#    outcome  = 'choice',
 #    obsID    = 'obsID',
+#    panelID  = 'id',
 #    pars     = c('price', 'feat', 'brand'),
 #    randPars = c(feat = 'n', brand = 'n'),
-#    # You should run a multistart for MXL models since they are non-convex
 #    numMultiStarts = 10
 #  )
 
@@ -36,16 +37,14 @@ wtp_mxl_pref
 ## ----eval=FALSE---------------------------------------------------------------
 #  mxl_wtp <- logitr(
 #    data       = yogurt,
-#    choice     = 'choice',
+#    outcome    = 'choice',
 #    obsID      = 'obsID',
+#    panelID    = 'id',
 #    pars       = c('feat', 'brand'),
 #    price      = 'price',
 #    randPars   = c(feat = 'n', brand = 'n'),
 #    modelSpace = 'wtp',
-#    # You should run a multistart for MXL models since they are non-convex
 #    numMultiStarts = 10,
-#    # Use the computed WTP from the preference space model as the starting
-#    # values for the first run:
 #    startVals = wtp_mxl_pref$Estimate
 #  )
 
@@ -55,3 +54,20 @@ summary(mxl_wtp)
 ## -----------------------------------------------------------------------------
 wtpCompare(mxl_pref, mxl_wtp, price = 'price')
 
+## ----eval=FALSE---------------------------------------------------------------
+#  library("logitr")
+#  
+#  mxl_pref_cor <- logitr(
+#    data     = yogurt,
+#    outcome  = 'choice',
+#    obsID    = 'obsID',
+#    panelID  = 'id',
+#    pars     = c('price', 'feat', 'brand'),
+#    randPars = c(feat = 'n', brand = 'n'),
+#    numMultiStarts = 10,
+#    correlation = TRUE
+#  )
+
+## -----------------------------------------------------------------------------
+summary(mxl_pref_cor)
+
